# This file contains all the sub-routines required to perform 
# NAS datastore related operations for WIR/Windows Replica

#!/usr/bin/perl

my $rootpath = '/usr/bp/wvf';

sub setup_nfs {

	print STDERR "Setting up NFS\n";
	my $id = shift;

	my $centos_version = `uname -r | sed -e "s/.*el//" | cut -c1`;
	chomp $centos_version;
	if ($centos_version > 6) {
        	if (! -e '/usr/lib/systemd/system/nfs.service') {
                	die "NFS is not installed\n";
        	}
	} else {
        	if (! -e '/etc/init.d/nfs') {
                	die "NFS is not installed\n";
        	}
	}

	remove_nfs_config($id);

	my $fsid = $id . "00";

	open NFSCONF, ">>/etc/exports" || die "Could not open /etc/exports.\n";
	print NFSCONF "#Unitrends_WIR start " . $id . " DO NOT EDIT BELOW\n";
	print NFSCONF "$rootpath *(rw,fsid=$fsid,crossmnt,async,wdelay)\n";
	$fsid += 1;
	my $i = 0;

	print NFSCONF "#Unitrends_WIR end DO NOT EDIT ABOVE\n\n";
	close NFSCONF;

	nfs_restart();
	print STDERR "NFS Datastore was setup successfully and nfs service was restarted.\n";
}

# Remove our previous NFS configuration for this instance
sub remove_nfs_config {
	
	my $id = shift;

	open NFSCONF, "</etc/exports";
	open NEWNFSCONF, ">/etc/exports.wirnew";
	while (<NFSCONF>) {
		if (/^#Unitrends_WIR start $id/) {
			# Skip until we get to a blank line or end marker
			while (<NFSCONF>) {
				if (/^$/ or /^#Unitrends_WIR end/) {
					next;
				}
			}
		}

		if (defined $_) {
			print NEWNFSCONF $_;
		}
	}

	close NEWNFSCONF;
	close NFSCONF;

	rename "/etc/exports", "/etc/exports.wirsave";
	if ($! != 0) {
		die "Failed to rename /etc/exports to /etc/exports.wirsave\n";
	}

	rename "/etc/exports.wirnew", "/etc/exports";
	if ($! != 0) {
		die "Failed to rename /etc/exports.wirnew to /etc/exports\n";
	}
}

sub nfs_restart {

	# First check if the 'nfs' service is running or not. If not, then, start it
	my $nfs_check_cmd = "service nfs status";
	`$nfs_check_cmd`;
	if($? != 0) {
		print STDERR "NFS service is not running. Starting it.\n";
		my $nfs_start_cmd = "service nfs start";
		`$nfs_start_cmd`;
		if($? != 0) {
			die "Unable to start NFS service for Windows Instant Recovery: $?\n";
		}
		# Since the service was started just now, no need to 'exportfs'
		return;
	}

	my $centos_version = `uname -r | sed -e "s/.*el//" | cut -c1`;
	chomp $centos_version;

	# Options passed to 'exportfs' (from man page for exportfs):
	#	-f => Flush everything out of the kernel's export table.
	#       -r => Reexport all directories, synchronizing /var/lib/nfs/etab with /etc/exports.
	#       -a => Export or unexport all directories.
	my $status = system("exportfs -fra >/dev/null 2>/dev/null");
	# Centos 7 seems to treat duplicate entries in /etc/exports as a failure so ignore return of 1 (bit shifted to 256)
	if ($status == 0 || ($centos_version > 6 && $status == 256)) {
		print STDERR "exportfs was successful !\n";
	}
	else {
		die "exportfs failed : $status\n";
	}
}


##############################################################
## Remove the NFS Datastore that was created for the winbm.iso
##############################################################

sub teardown {
	my $id = shift;

	
}



















1;
